#if !defined(LEXER_HH)
#define LEXER_HH

#include <iostream>

#include "Token.hh"
#include "ErrorManager.hh"

///////////////////////////////////////////////////////////////////////////
class Lexer {
///////////////////////////////////////////////////////////////////////////

public :

  Lexer( std::istream& is, ErrorManager& error ) : 
    inStream_(is), error_(error) { }
  ~Lexer( void ) { }

  void next() {
    char ch = (char)Token::NIL;
    do {
      ch = inStream_.get();
      if (inStream_.eof()) {
	curToken_.setPartOfSpeech(Token::EOFF);
	curToken_.setLexeme((char)Token::NIL);
	return;
      }
    } while (isLayoutChar_(ch));
    if (ch >= '0' && ch <= '9') {
      curToken_.setPartOfSpeech(Token::DGT);
    } else {
      curToken_.setPartOfSpeech((int)ch);
    }
    curToken_.setLexeme(ch);
  }
  const Token& cur() {
    return curToken_;
  }

private :
  std::istream& inStream_;
  ErrorManager& error_;
  Token         curToken_;

  bool isLayoutChar_( int ch ) {
    switch (ch) {
    case ' ': case '\t' : case '\n': return true;
    default : return false;
    }
  }

}; // End of class Lexer

#endif
