#include <fstream>

// Front End
#include "Lexer.hh"
#include "Parser.hh"

// Intermediate representation
#include "AstManager.hh"

// Back End
#include "AsmGenerator.hh"

// Error Handling
#include "ErrorManager.hh"

int main(int argc, char* argv[]) {
  
  ErrorManager error;

  if (argc < 1) {
    error("No input file given");
  } else {
    std::ifstream ifs;
    ifs.open(argv[1]);
    Lexer lex(ifs, error);
    AstManager ast;
    Parser parse(lex, ast, error);
    AstNode* program = parse();
    AsmGenerator generateCode(std::cout);
    generateCode(program);
    ifs.close();
  }  
  return 0;

} // End of main
